@@ -12,7 +12,7 @@ from tools.config.save import save, save_session
 #
 # Exported variables (internal configuration)
 #
-version = "1.3.2"
+version = "1.3.4"
 tools_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 
 # Keys saved in the config file (mostly what we ask in 'waydroid init')
@@ -20,7 +20,8 @@ config_keys = ["arch",
                "images_path",
                "vendor_type",
                "system_datetime",
-               "vendor_datetime"]
+               "vendor_datetime",
+               "suspend_action"]
 
 session_config_keys = ["user_name",
                        "user_id",
@@ -43,7 +44,11 @@ defaults = {
     "vendor_type": "MAINLINE",
     "system_datetime": "0",
     "vendor_datetime": "0",
-    "preinstalled_images_path": "/usr/share/waydroid-extra/images"
+    "preinstalled_images_paths": [
+        "/etc/waydroid-extra/images",
+        "/usr/share/waydroid-extra/images",
+    ],
+    "suspend_action": "freeze"
 }
 defaults["images_path"] = defaults["work"] + "/images"
 defaults["rootfs"] = defaults["work"] + "/rootfs"
